@@ -73,13 +73,9 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-#define PARENT_TYPE E_TYPE_ACCOUNT_LIST
-
 #define CONF_KEY_SELECTED_CAL_SOURCES "/apps/evolution/calendar/display/selected_calendars"
 #define CONF_KEY_SELECTED_TASKS_SOURCES "/apps/evolution/calendar/tasks/selected_tasks"
 
-static EAccountListClass *parent_class = NULL;
-
 static void dispose (GObject *object);
 static void finalize (GObject *object);
 
@@ -97,18 +93,23 @@ static gboolean exchange_camel_urls_is_equal (const gchar *url1,
 					      const gchar *url2);
 static void remove_selected_non_offline_esources (ExchangeAccount *account,
 						  const gchar *gconf_key);
+
+G_DEFINE_TYPE (
+	ExchangeConfigListener,
+	exchange_config_listener,
+	E_TYPE_ACCOUNT_LIST)
+
 static void
-class_init (GObjectClass *object_class)
+exchange_config_listener_class_init (ExchangeConfigListenerClass *class)
 {
-	EAccountListClass *e_account_list_class =
-		E_ACCOUNT_LIST_CLASS (object_class);
+	GObjectClass *object_class;
+	EAccountListClass *e_account_list_class;
 
-	parent_class = g_type_class_ref (PARENT_TYPE);
-
-	/* virtual method override */
+	object_class = G_OBJECT_CLASS (class);
 	object_class->dispose = dispose;
 	object_class->finalize = finalize;
 
+	e_account_list_class = E_ACCOUNT_LIST_CLASS (class);
 	e_account_list_class->account_added   = account_added;
 	e_account_list_class->account_changed = account_changed;
 	e_account_list_class->account_removed = account_removed;
@@ -135,11 +136,8 @@ class_init (GObjectClass *object_class)
 }
 
 static void
-init (GObject *object)
+exchange_config_listener_init (ExchangeConfigListener *config_listener)
 {
-	ExchangeConfigListener *config_listener =
-		EXCHANGE_CONFIG_LISTENER (object);
-
 	config_listener->priv = g_new0 (ExchangeConfigListenerPrivate, 1);
 }
 
@@ -159,7 +157,7 @@ dispose (GObject *object)
 		config_listener->priv->gconf = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	G_OBJECT_CLASS (exchange_config_listener_parent_class)->dispose (object);
 }
 
 static void
@@ -172,11 +170,9 @@ finalize (GObject *object)
 	g_free (config_listener->priv->configured_uri);
 	g_free (config_listener->priv);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (exchange_config_listener_parent_class)->finalize (object);
 }
 
-E2K_MAKE_TYPE (exchange_config_listener, ExchangeConfigListener, class_init, init, PARENT_TYPE)
-
 #define EVOLUTION_URI_PREFIX     "evolution:/"
 #define EVOLUTION_URI_PREFIX_LEN (sizeof (EVOLUTION_URI_PREFIX) - 1)
 
@@ -1007,7 +1003,10 @@ requires_relogin (gchar *current_url, gchar *new_url)
 {
 	E2kUri *current_uri, *new_uri;
 	const gchar *current_param_val, *new_param_val;
-	const gchar *params [] = { "owa_url", "ad_server", "use_ssl" };
+	const gchar *params [] = {
+		"owa-url",
+		"gc-server-name",
+		"security-method" };
 	const gint n_params = G_N_ELEMENTS (params);
 	gint i;
 	gboolean relogin = FALSE;
@@ -1397,10 +1396,10 @@ exchange_camel_urls_is_equal (const gchar *url1, const gchar *url2)
 	gchar *param1, *param2;
 	const gchar *params[] = {
 		"auth",
-		"owa_url",
-		"owa_path",
+		"owa-url",
+		"owa-path",
 		"mailbox",
-		"ad_server",
+		"gc-server-name",
 	};
 	const gint n_params = 5;
 	gint i;
